# vnpy_insight
华泰insight数据服务vnpy datafeed

# 安装
## 源码安装 
下载源码, cd到源码目录，执行
```angular2html
pip install .
```
## pip源安装: 未上传
```angular2html
pip install vnpy_insight
```

# 参考资料
- https://findata-insight.htsc.com:9151/help/
